==> v0.9.0.tar.gz: itgmania-0.9.0/src/archutils/Win32/Crash.h <==
#ifndef CRASH_H
#define CRASH_H

#include <cstddef>
#include <cstdint>
#include <windows.h>

/** @brief Win32 crash handling. */
namespace CrashHandler
{
	extern long __stdcall ExceptionHandler(struct _EXCEPTION_POINTERS *ExceptionInfo);

	void do_backtrace( const void **buf, std::size_t size, HANDLE hProcess, HANDLE hThread, const CONTEXT *pContext );
	void SymLookup( const void *ptr, char *buf );
	void ForceCrash( const char *reason );
	void ForceDeadlock( RString reason, std::uint64_t iID );

	/* Inform the crash handler of a foreground window that may be fullscreen.
	 * If set, the crash handler will attempt to hide the window or reset the
	 * video mode. */
	void SetForegroundWindow( HWND hWnd );

	void CrashHandlerHandleArgs( int argc, char* argv[] );
};

#endif
/*
 * (c) 1998-2001 Avery Lee
 * (c) 2003-2004 Glenn Maynard
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, provided that the above
 * copyright notice(s) and this permission notice appear in all copies of
 * the Software and that both the above copyright notice(s) and this
 * permission notice appear in supporting documentation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
 * THIRD PARTY RIGHTS. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS
 * INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT
 * OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
 * OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
 * OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 */

==> v1.0.0.tar.gz: itgmania-1.0.0/src/archutils/Win32/Crash.h <==
#ifndef CRASH_H
#define CRASH_H

#include <cstddef>
#include <cstdint>
#include <windows.h>

/** @brief Win32 crash handling. */
namespace CrashHandler
{
	extern long __stdcall ExceptionHandler(struct _EXCEPTION_POINTERS *ExceptionInfo);

	void do_backtrace( const void **buf, size_t size, HANDLE hProcess, HANDLE hThread, const CONTEXT *pContext );
	void SymLookup( const void *ptr, char *buf );
	void ForceCrash( const char *reason );
	void ForceDeadlock( RString reason, uint64_t iID );

	/* Inform the crash handler of a foreground window that may be fullscreen.
	 * If set, the crash handler will attempt to hide the window or reset the
	 * video mode. */
	void SetForegroundWindow( HWND hWnd );

	void CrashHandlerHandleArgs( int argc, char* argv[] );
};

#endif
/*
 * (c) 1998-2001 Avery Lee
 * (c) 2003-2004 Glenn Maynard
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, provided that the above
 * copyright notice(s) and this permission notice appear in all copies of
 * the Software and that both the above copyright notice(s) and this
 * permission notice appear in supporting documentation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
 * THIRD PARTY RIGHTS. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS
 * INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT
 * OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
 * OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
 * OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 */
